==> react-native-digitcamera-1.6.10.tgz: package/src/Screens/PreviewMedia.js <==
import React, { useEffect, useRef, useState } from "react";
const iOS = Platform.OS === "ios";
import {
  Alert,
  BackHandler,
  Image,
  Platform,
  StatusBar,
  StyleSheet,
  Text,
  TouchableOpacity,
  View,
} from "react-native";
import Colors from "react-native-digitcamera/src/common/Colors";
import { SafeAreaView } from "react-native-safe-area-context";
import VideoPlayer from "react-native-video-player";
import {
  SCREEN_HEIGHT,
  SCREEN_WIDTH,
} from "react-native-digitcamera/src/common/Constants";
import { Spinner } from "react-native-digitcamera/src/common/ThemedComponents";
import Database from "../../../../Components/common/Database";
import Orientation from "react-native-orientation";
import { async } from "validate.js";

const retake = require("../common/Image/retake.png");
const proceed = require("../common/Image/proceed.png");

const PreviewMedia = ({ navigation, route }) => {
  const { uri, DocumentImageName, onRetry, onProceed, rcbPreviewCallback } = route.params;
  useEffect(() => {
    let Immersive = undefined;
    let restoreImmersive = undefined;
    if (!iOS) {
      Immersive = require("react-native-immersive").Immersive;
      Immersive.setImmersive(true);
      restoreImmersive = () => {
        __DEV__ && console.log("Immersive state changed!");
        Immersive.setImmersive(true);
      };
      Immersive.addImmersiveListener(restoreImmersive);
    }

    let unsubscribe = navigation.addListener("focus", () => {
      Orientation.lockToLandscapeLeft();
    });
    // disabled back handler
    const backHandler = BackHandler.addEventListener(
      "hardwareBackPress",
      () => {
        return true;
      }
    );

    return () => {
      if (Immersive !== undefined) {
        Immersive.off();
        Immersive.removeImmersiveListener(restoreImmersive);
      }

      backHandler.remove();
      unsubscribe();
    };
  }, []);
  return (
    <SafeAreaView
      edges={iOS ? ["top", "bottom", "right"] : []}
      style={styles.safeArea}
    >
      <View style={styles.main}>
        <Spinner loading={false} />
        <StatusBar hidden={true} />
        {/* Image View */}
        <View style={styles.imageView}>
          {/* Image */}
          {DocumentImageName == "VDO" ? (
            <VideoPlayer
              video={{ uri: uri }}
              pauseOnPress={true}
              autoplay={true}
              disableSeek={true}
            />
          ) : (
            <View>
              <Image source={{ uri: uri }} style={styles.imageStyle} />
            </View>
          )}
        </View>
        {/* Button View */}
        <View style={styles.buttonView}>
          {/* Retake View */}
          <View style={styles.retakeView}>
            <TouchableOpacity
              onPress={() => {
                if (onRetry !== undefined) {
                  onRetry(uri, DocumentImageName);
                  navigation.pop();
                }
              }}
            >
              <Image
                source={retake}
                style={{ width: 18, height: 18, alignSelf: "center" }}
              />
              <Text style={styles.retakeText}>{"Retake"}</Text>
            </TouchableOpacity>
          </View>
          {/* Proceed View */}
          <View style={styles.proceedView}>
            <TouchableOpacity
              onPress={() => {
                if (DocumentImageName === "RCB2" || DocumentImageName === "RCB1") {
                  /*@RCBPREVIEW*/
                  onProceed(uri, DocumentImageName)
                  rcbPreviewCallback()
                  return
                }
                if (onProceed !== undefined) {
                  navigation.pop();
                  onProceed(uri, DocumentImageName);
                }
              }}
            >
              <Image
                source={proceed}
                style={{ width: 49, height: 49, alignSelf: "center" }}
              />
              <Text style={styles.retakeText}>{"Proceed"}</Text>
            </TouchableOpacity>
          </View>
          {/* Blank View */}
          <View style={styles.blankView} />
        </View>
      </View>
    </SafeAreaView>
  );
};
export default PreviewMedia;

const styles = StyleSheet.create({
  safeArea: {
    flex: 1,
    backgroundColor: Colors.darkBlack,
  },
  main: {
    flex: 1,
    flexDirection: "row",
  },
  buttonView: {
    flex: 0.1,
    backgroundColor: "#000000",
  },
  imageView: {
    flex: 0.9,
    alignSelf: "center",
  },
  retakeView: {
    flex: 0.333333,
    justifyContent: "center",
  },
  proceedView: {
    flex: 0.333333,
    justifyContent: "center",
  },
  blankView: {
    flex: 0.3333333,
  },
  retakeText: {
    fontFamily: "Muli-Regular",
    fontSize: 11,
    alignSelf: "center",
    marginTop: 5,
    color: "#FFFFFF",
  },
  infoTextView: {
    // flex:0.1,
    position: "absolute",
    width: SCREEN_HEIGHT,
    height: 48,
    backgroundColor: "#000000",
    opacity: 0.58,
    justifyContent: "center",
  },
  infoText: {
    fontFamily: "Muli-SemiBold",
    fontSize: 14,
    color: "#FFFFFF",
    marginLeft: 24,
    marginRight: 24,
  },
  imageStyle: {
    width: "100%",
    height: "100%",
    resizeMode: "contain",
    alignSelf: "center",
  },
});

==> react-native-digitcamera-1.6.11.tgz: package/src/Screens/PreviewMedia.js <==
import React, { useEffect, useRef, useState } from "react";
const iOS = Platform.OS === "ios";
import {
  Alert,
  BackHandler,
  Image,
  Platform,
  StatusBar,
  StyleSheet,
  Text,
  TouchableOpacity,
  View,
} from "react-native";
import Colors from "react-native-digitcamera/src/common/Colors";
import { SafeAreaView } from "react-native-safe-area-context";
import VideoPlayer from "react-native-video-player";
import {
  SCREEN_HEIGHT,
  SCREEN_WIDTH,
} from "react-native-digitcamera/src/common/Constants";
import { Spinner } from "react-native-digitcamera/src/common/ThemedComponents";
import Database from "../../../../Components/common/Database";
import Orientation from "react-native-orientation";
import { async } from "validate.js";

/*@RCBPREVIEW*/
import { useDispatch } from "react-redux";

const retake = require("../common/Image/retake.png");
const proceed = require("../common/Image/proceed.png");

const PreviewMedia = ({ navigation, route }) => {
  const { uri, DocumentImageName, onRetry, onProceed } =
    route.params;

  /*@RCBPREVIEW*/
  const dispatch = useDispatch();

  useEffect(() => {
    let Immersive = undefined;
    let restoreImmersive = undefined;
    if (!iOS) {
      Immersive = require("react-native-immersive").Immersive;
      Immersive.setImmersive(true);
      restoreImmersive = () => {
        __DEV__ && console.log("Immersive state changed!");
        Immersive.setImmersive(true);
      };
      Immersive.addImmersiveListener(restoreImmersive);
    }

    let unsubscribe = navigation.addListener("focus", () => {
      Orientation.lockToLandscapeLeft();
    });
    // disabled back handler
    const backHandler = BackHandler.addEventListener(
      "hardwareBackPress",
      () => {
        return true;
      }
    );

    return () => {
      if (Immersive !== undefined) {
        Immersive.off();
        Immersive.removeImmersiveListener(restoreImmersive);
      }

      backHandler.remove();
      unsubscribe();
    };
  }, []);
  return (
    <SafeAreaView
      edges={iOS ? ["top", "bottom", "right"] : []}
      style={styles.safeArea}
    >
      <View style={styles.main}>
        <Spinner loading={false} />
        <StatusBar hidden={true} />
        {/* Image View */}
        <View style={styles.imageView}>
          {/* Image */}
          {DocumentImageName == "VDO" ? (
            <VideoPlayer
              video={{ uri: uri }}
              pauseOnPress={true}
              autoplay={true}
              disableSeek={true}
            />
          ) : (
            <View>
              <Image source={{ uri: uri }} style={styles.imageStyle} />
            </View>
          )}
        </View>
        {/* Button View */}
        <View style={styles.buttonView}>
          {/* Retake View */}
          <View style={styles.retakeView}>
            <TouchableOpacity
              onPress={() => {
                if (onRetry !== undefined) {
                  onRetry(uri, DocumentImageName);
                  navigation.pop();
                }
              }}
            >
              <Image
                source={retake}
                style={{ width: 18, height: 18, alignSelf: "center" }}
              />
              <Text style={styles.retakeText}>{"Retake"}</Text>
            </TouchableOpacity>
          </View>
          {/* Proceed View */}
          <View style={styles.proceedView}>
            <TouchableOpacity
              onPress={() => {

                /* @RCBPREVIEW */
                if (DocumentImageName.includes("RCB")) {

                  dispatch({
                    type: "ADD_RCB_IMAGE",
                    payload: {
                      name: DocumentImageName,
                      image: uri,
                      info: `RC ${DocumentImageName === "RCB1" ? "Front" : "Back"} Page`
                    }
                  })

                }

                if (onProceed !== undefined) {

                  onProceed(uri, DocumentImageName);
                  /* @RCBPREVIEW */
                  if (DocumentImageName === "RCB2") {
                    navigation.navigate("RCBPreviewScreen", {
                      goToDBD: true
                    })
                  }
                  else {
                    navigation.pop();
                  }
                }
              }}
            >
              <Image
                source={proceed}
                style={{ width: 49, height: 49, alignSelf: "center" }}
              />
              <Text style={styles.retakeText}>{"Proceed"}</Text>
            </TouchableOpacity>
          </View>
          {/* Blank View */}
          <View style={styles.blankView} />
        </View>
      </View>
    </SafeAreaView>
  );
};
export default PreviewMedia;

const styles = StyleSheet.create({
  safeArea: {
    flex: 1,
    backgroundColor: Colors.darkBlack,
  },
  main: {
    flex: 1,
    flexDirection: "row",
  },
  buttonView: {
    flex: 0.1,
    backgroundColor: "#000000",
  },
  imageView: {
    flex: 0.9,
    alignSelf: "center",
  },
  retakeView: {
    flex: 0.333333,
    justifyContent: "center",
  },
  proceedView: {
    flex: 0.333333,
    justifyContent: "center",
  },
  blankView: {
    flex: 0.3333333,
  },
  retakeText: {
    fontFamily: "Muli-Regular",
    fontSize: 11,
    alignSelf: "center",
    marginTop: 5,
    color: "#FFFFFF",
  },
  infoTextView: {
    // flex:0.1,
    position: "absolute",
    width: SCREEN_HEIGHT,
    height: 48,
    backgroundColor: "#000000",
    opacity: 0.58,
    justifyContent: "center",
  },
  infoText: {
    fontFamily: "Muli-SemiBold",
    fontSize: 14,
    color: "#FFFFFF",
    marginLeft: 24,
    marginRight: 24,
  },
  imageStyle: {
    width: "100%",
    height: "100%",
    resizeMode: "contain",
    alignSelf: "center",
  },
});
